# Generated by Django 2.0.4 on 2019-01-22 16:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tradukoj', '0012_auto_20181219_1842'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gettextfile',
            name='file',
            field=models.FileField(upload_to='uploads/tradukoj'),
        ),
    ]
