# Generated by Django 2.0.4 on 2018-05-16 09:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tradukoj', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='translationkey',
            name='key',
        ),
        migrations.AddField(
            model_name='translationkey',
            name='text',
            field=models.CharField(default='hello from one test', max_length=255, unique=True, verbose_name='text key'),
            preserve_default=False,
        ),
    ]
