# Generated by Django 2.0.4 on 2018-05-16 19:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tradukoj', '0003_auto_20180516_1859'),
    ]

    operations = [
        migrations.AddField(
            model_name='bcp47',
            name='enabled',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='bcp47',
            name='name',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Lang name'),
        ),
    ]
