# Generated by Django 2.0.4 on 2018-11-15 20:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tradukoj', '0006_bcp47_direction'),
    ]

    operations = [
        migrations.AddField(
            model_name='bcp47',
            name='default',
            field=models.BooleanField(default=False),
        ),
    ]
